package com.huimv.eartag.manager.controller;


import com.github.pagehelper.PageInfo;
import com.huimv.eartag.manager.entity.Result;
import com.huimv.eartag.manager.entity.StatusCode;
import com.huimv.eartag.manager.pojo.EartagData;
import com.huimv.eartag.manager.service.EartagDataService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/****
 * @Author:shenkunlin
 * @Description:
 * @Date 2019/6/14 0:18
 *****/

@RestController
@RequestMapping("/eartagData")
@CrossOrigin
public class EartagDataController {

    @Autowired
    private EartagDataService eartagDataService;

    /***
     * EartagData分页条件搜索实现
     * @param map
     * @param page
     * @param size
     * @return
     */
    @PostMapping(value = "/search/{page}/{size}" )
    public Result<PageInfo> findPage(@RequestBody(required = false)Map map, @PathVariable  int page, @PathVariable  int size){
        //调用EartagDataService实现分页条件查询EartagData
        PageInfo<Map> pageInfo = eartagDataService.findPage(map, page, size);
        return new Result(true, StatusCode.OK,"查询成功",pageInfo);
    }

    @PostMapping(value = "/searchData" )
    public Result ss(@RequestBody(required = false)Map map){
        //调用EartagDataService实现分页条件查询EartagData
       Map map1 = eartagDataService.searchData(map);
        return new Result(true, StatusCode.OK,"查询成功",map1);
    }
    /***
     * EartagData分页搜索实现
     * @param page:当前页
     * @param size:每页显示多少条
     * @return
     */
    @GetMapping(value = "/search/{page}/{size}" )
    public Result<PageInfo> findPage(@PathVariable  int page, @PathVariable  int size){
        //调用EartagDataService实现分页查询EartagData
        PageInfo<EartagData> pageInfo = eartagDataService.findPage(page, size);
        return new Result<PageInfo>(true,StatusCode.OK,"查询成功",pageInfo);
    }

    /***
     * 多条件搜索品牌数据
     * @param eartagData
     * @return
     */
    @PostMapping(value = "/search" )
    public Result<List<EartagData>> findList(@RequestBody(required = false)  EartagData eartagData){
        //调用EartagDataService实现条件查询EartagData
        List<EartagData> list = eartagDataService.findList(eartagData);
        return new Result<List<EartagData>>(true,StatusCode.OK,"查询成功",list);
    }

    /***
     * 根据ID删除品牌数据
     * @param id
     * @return
     */
    @DeleteMapping(value = "/{id}" )
    public Result delete(@PathVariable Integer id){
        //调用EartagDataService实现根据主键删除
        eartagDataService.delete(id);
        return new Result(true,StatusCode.OK,"删除成功");
    }

    /***
     * 修改EartagData数据
     * @param eartagData
     * @param id
     * @return
     */
    @PutMapping(value="/{id}")
    public Result update(@RequestBody  EartagData eartagData,@PathVariable Integer id){
        //设置主键值
        eartagData.setId(id);
        //调用EartagDataService实现修改EartagData
        eartagDataService.update(eartagData);
        return new Result(true,StatusCode.OK,"修改成功");
    }

    /***
     * 新增EartagData数据
     * @param eartagData
     * @return
     */
    @PostMapping
    public Result add(@RequestBody   EartagData eartagData){
        //调用EartagDataService实现添加EartagData
        eartagDataService.add(eartagData);
        return new Result(true, StatusCode.OK,"添加成功");
    }

    /***
     * 根据ID查询EartagData数据
     * @param id
     * @return
     */
    @GetMapping("/{id}")
    public Result<EartagData> findById(@PathVariable Integer id){
        //调用EartagDataService实现根据主键查询EartagData
        EartagData eartagData = eartagDataService.findById(id);
        return new Result<EartagData>(true,StatusCode.OK,"查询成功",eartagData);
    }

    /***
     * 查询EartagData全部数据
     * @return
     */
    @GetMapping
    public Result<List<EartagData>> findAll(){
        //调用EartagDataService实现查询所有EartagData
        List<EartagData> list = eartagDataService.findAll();
        return new Result<List<EartagData>>(true, StatusCode.OK,"查询成功",list) ;
    }
}
