package com.huimv.eartag.manager.controller;


import com.github.pagehelper.PageInfo;
import com.huimv.eartag.manager.entity.Result;
import com.huimv.eartag.manager.entity.StatusCode;
import com.huimv.eartag.manager.pojo.EartagTemperature;
import com.huimv.eartag.manager.service.EartagTemperatureService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/****
 * @Author:shenkunlin
 * @Description:
 * @Date 2019/6/14 0:18
 *****/

@RestController
@RequestMapping("/eartagTemperature")
@CrossOrigin
public class EartagTemperatureController {

    @Autowired
    private EartagTemperatureService eartagTemperatureService;

    /***
     * EartagTemperature分页条件搜索实现
     * @param eartagTemperature
     * @param page
     * @param size
     * @return
     */
    @PostMapping(value = "/search/{page}/{size}" )
    public Result<PageInfo> findPage(@RequestBody(required = false) EartagTemperature eartagTemperature, @PathVariable  int page, @PathVariable  int size){
        //调用EartagTemperatureService实现分页条件查询EartagTemperature
        PageInfo<EartagTemperature> pageInfo = eartagTemperatureService.findPage(eartagTemperature, page, size);
        return new Result(true, StatusCode.OK,"查询成功",pageInfo);
    }

    /***
     * EartagTemperature分页搜索实现
     * @param page:当前页
     * @param size:每页显示多少条
     * @return
     */
    @GetMapping(value = "/search/{page}/{size}" )
    public Result<PageInfo> findPage(@PathVariable  int page, @PathVariable  int size){
        //调用EartagTemperatureService实现分页查询EartagTemperature
        PageInfo<EartagTemperature> pageInfo = eartagTemperatureService.findPage(page, size);
        return new Result<PageInfo>(true, StatusCode.OK,"查询成功",pageInfo);
    }

    /***
     * 多条件搜索品牌数据
     * @param eartagTemperature
     * @return
     */
    @PostMapping(value = "/search" )
    public Result<List<EartagTemperature>> findList(@RequestBody(required = false)  EartagTemperature eartagTemperature){
        //调用EartagTemperatureService实现条件查询EartagTemperature
        List<EartagTemperature> list = eartagTemperatureService.findList(eartagTemperature);
        return new Result<List<EartagTemperature>>(true,StatusCode.OK,"查询成功",list);
    }

    /***
     * 根据ID删除品牌数据
     * @param id
     * @return
     */
    @DeleteMapping(value = "/{id}" )
    public Result delete(@PathVariable Integer id){
        //调用EartagTemperatureService实现根据主键删除
        eartagTemperatureService.delete(id);
        return new Result(true,StatusCode.OK,"删除成功");
    }

    /***
     * 修改EartagTemperature数据
     * @param eartagTemperature
     * @param id
     * @return
     */
    @PutMapping(value="/{id}")
    public Result update(@RequestBody  EartagTemperature eartagTemperature,@PathVariable Integer id){
        //设置主键值
        eartagTemperature.setId(id);
        //调用EartagTemperatureService实现修改EartagTemperature
        eartagTemperatureService.update(eartagTemperature);
        return new Result(true,StatusCode.OK,"修改成功");
    }

    /***
     * 新增EartagTemperature数据
     * @param eartagTemperature
     * @return
     */
    @PostMapping
    public Result add(@RequestBody   EartagTemperature eartagTemperature){
        //调用EartagTemperatureService实现添加EartagTemperature
        eartagTemperatureService.add(eartagTemperature);
        return new Result(true,StatusCode.OK,"添加成功");
    }

    /***
     * 根据ID查询EartagTemperature数据
     * @param id
     * @return
     */
    @GetMapping("/{id}")
    public Result<EartagTemperature> findById(@PathVariable Integer id){
        //调用EartagTemperatureService实现根据主键查询EartagTemperature
        EartagTemperature eartagTemperature = eartagTemperatureService.findById(id);
        return new Result<EartagTemperature>(true,StatusCode.OK,"查询成功",eartagTemperature);
    }

    /***
     * 查询EartagTemperature全部数据
     * @return
     */
    @GetMapping
    public Result<List<EartagTemperature>> findAll(){
        //调用EartagTemperatureService实现查询所有EartagTemperature
        List<EartagTemperature> list = eartagTemperatureService.findAll();
        return new Result<List<EartagTemperature>>(true, StatusCode.OK,"查询成功",list) ;
    }
}
