package com.huimv.eartag.manager.service.impl;


import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import com.huimv.eartag.manager.dao.EartagTemperatureMapper;
import com.huimv.eartag.manager.pojo.EartagTemperature;
import com.huimv.eartag.manager.service.EartagTemperatureService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;
import tk.mybatis.mapper.entity.Example;

import java.util.List;

/****
 * @Author:shenkunlin
 * @Description:EartagTemperature业务层接口实现类
 * @Date 2019/6/14 0:16
 *****/
@Service
public class EartagTemperatureServiceImpl implements EartagTemperatureService {

    @Autowired
    private EartagTemperatureMapper eartagTemperatureMapper;


    /**
     * EartagTemperature条件+分页查询
     * @param eartagTemperature 查询条件
     * @param page 页码
     * @param size 页大小
     * @return 分页结果
     */
    @Override
    public PageInfo<EartagTemperature> findPage(EartagTemperature eartagTemperature, int page, int size){
        //分页
        PageHelper.startPage(page,size);
        //搜索条件构建
        Example example = createExample(eartagTemperature);
        //执行搜索
        return new PageInfo<EartagTemperature>(eartagTemperatureMapper.selectByExample(example));
    }

    /**
     * EartagTemperature分页查询
     * @param page
     * @param size
     * @return
     */
    @Override
    public PageInfo<EartagTemperature> findPage(int page, int size){
        //静态分页
        PageHelper.startPage(page,size);
        //分页查询
        return new PageInfo<EartagTemperature>(eartagTemperatureMapper.selectAll());
    }

    /**
     * EartagTemperature条件查询
     * @param eartagTemperature
     * @return
     */
    @Override
    public List<EartagTemperature> findList(EartagTemperature eartagTemperature){
        //构建查询条件
        Example example = createExample(eartagTemperature);
        //根据构建的条件查询数据
        return eartagTemperatureMapper.selectByExample(example);
    }


    /**
     * EartagTemperature构建查询对象
     * @param eartagTemperature
     * @return
     */
    public Example createExample(EartagTemperature eartagTemperature){
        Example example=new Example(EartagTemperature.class);
        Example.Criteria criteria = example.createCriteria();
        if(eartagTemperature!=null){
            // id
            if(!StringUtils.isEmpty(eartagTemperature.getId())){
                    criteria.andEqualTo("id",eartagTemperature.getId());
            }
            // 
            if(!StringUtils.isEmpty(eartagTemperature.getHeader())){
                    criteria.andEqualTo("header",eartagTemperature.getHeader());
            }
            // 
            if(!StringUtils.isEmpty(eartagTemperature.getDeviceId())){
                    criteria.andEqualTo("deviceId",eartagTemperature.getDeviceId());
            }
            // 
            if(!StringUtils.isEmpty(eartagTemperature.getCmd())){
                    criteria.andEqualTo("cmd",eartagTemperature.getCmd());
            }
            // 
            if(!StringUtils.isEmpty(eartagTemperature.getSerialNo())){
                    criteria.andEqualTo("serialNo",eartagTemperature.getSerialNo());
            }
            // 
            if(!StringUtils.isEmpty(eartagTemperature.getValue())){
                    criteria.andEqualTo("value",eartagTemperature.getValue());
            }
            // 
            if(!StringUtils.isEmpty(eartagTemperature.getCreateDate())){
                    criteria.andEqualTo("createDate",eartagTemperature.getCreateDate());
            }
            // 
            if(!StringUtils.isEmpty(eartagTemperature.getCheckNumber())){
                    criteria.andEqualTo("checkNumber",eartagTemperature.getCheckNumber());
            }
            // 
            if(!StringUtils.isEmpty(eartagTemperature.getTail())){
                    criteria.andEqualTo("tail",eartagTemperature.getTail());
            }
        }
        return example;
    }

    /**
     * 删除
     * @param id
     */
    @Override
    public void delete(Integer id){
        eartagTemperatureMapper.deleteByPrimaryKey(id);
    }

    /**
     * 修改EartagTemperature
     * @param eartagTemperature
     */
    @Override
    public void update(EartagTemperature eartagTemperature){
        eartagTemperatureMapper.updateByPrimaryKey(eartagTemperature);
    }

    /**
     * 增加EartagTemperature
     * @param eartagTemperature
     */
    @Override
    public void add(EartagTemperature eartagTemperature){
        eartagTemperatureMapper.insert(eartagTemperature);
    }

    /**
     * 根据ID查询EartagTemperature
     * @param id
     * @return
     */
    @Override
    public EartagTemperature findById(Integer id){
        return  eartagTemperatureMapper.selectByPrimaryKey(id);
    }

    /**
     * 查询EartagTemperature全部数据
     * @return
     */
    @Override
    public List<EartagTemperature> findAll() {
        return eartagTemperatureMapper.selectAll();
    }
}
