package com.huimv.eartag.manager.service.impl;



import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.huimv.eartag.manager.dao.EartagDampnessMapper;
import com.huimv.eartag.manager.dao.EartagTemperatureMapper;
import com.huimv.eartag.manager.dao.JqidMapper;
import com.huimv.eartag.manager.pojo.EartagDampness;
import com.huimv.eartag.manager.pojo.EartagData;
import com.huimv.eartag.manager.pojo.EartagTemperature;
import com.huimv.eartag.manager.pojo.Jqid;
import com.huimv.eartag.manager.service.FarmInfoService;
import com.huimv.eartag.manager.service.JqidService;
import com.huimv.eartag.manager.service.PigHomeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;
import tk.mybatis.mapper.entity.Example;

import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;

/****
 * @Author:shenkunlin
 * @Description:Jqid业务层接口实现类
 * @Date 2019/6/14 0:16
 *****/
@Service
public class JqidServiceImpl implements JqidService {

    @Autowired
    private JqidMapper jqidMapper;


    @Autowired
    private FarmInfoService farmInfoService;

    @Autowired
    private PigHomeService pigHomeService ;
    /**
     * Jqid条件+分页查询
     * @param jqid 查询条件
     * @param page 页码
     * @param size 页大小
     * @return 分页结果
     */
    @Override
    public PageInfo<Jqid> findPage(Jqid jqid, int page, int size){
        //分页
        PageHelper.startPage(page,size);
        //搜索条件构建
        Example example = createExample(jqid);
        //执行搜索
        return new PageInfo<Jqid>(jqidMapper.selectByExample(example));
    }

    /**
     * Jqid分页查询
     * @param page
     * @param size
     * @return
     */
    @Override
    public PageInfo<Jqid> findPage(int page, int size){
        //静态分页
        PageHelper.startPage(page,size);
        //分页查询
        return new PageInfo<Jqid>(jqidMapper.selectAll());
    }

    /**
     * Jqid条件查询
     * @param jqid
     * @return
     */
    @Override
    public List<Jqid> findList(Jqid jqid){
        //构建查询条件
        Example example = createExample(jqid);
        //根据构建的条件查询数据
        return jqidMapper.selectByExample(example);
    }


    /**
     * Jqid构建查询对象
     * @param jqid
     * @return
     */
    public Example createExample(Jqid jqid){
        Example example=new Example(Jqid.class);
        Example.Criteria criteria = example.createCriteria();
        if(jqid!=null){
            // 
            if(!StringUtils.isEmpty(jqid.getId())){
                    criteria.andEqualTo("id",jqid.getId());
            }
            // 牧场名称
            if(!StringUtils.isEmpty(jqid.getFarmNameid())){
                    criteria.andEqualTo("farmNameid",jqid.getFarmNameid());
            }
            // 猪舍名称
            if(!StringUtils.isEmpty(jqid.getPigHomeid())){
                    criteria.andEqualTo("pigHomeid",jqid.getPigHomeid());
            }
            // 备注
            if(!StringUtils.isEmpty(jqid.getRemarmk())){
                    criteria.andEqualTo("remarmk",jqid.getRemarmk());
            }
            // 机器id
            if(!StringUtils.isEmpty(jqid.getJQID())){
                    criteria.andEqualTo("JQID",jqid.getJQID());
            }
            // 机器编码
            if(!StringUtils.isEmpty(jqid.getJQcode())){
                    criteria.andEqualTo("JQcode",jqid.getJQcode());
            }
            // 机器名称
            if(!StringUtils.isEmpty(jqid.getFarmName())){
                    criteria.andEqualTo("farmName",jqid.getFarmName());
            }
            // 猪舍名称
            if(!StringUtils.isEmpty(jqid.getPigHome())){
                    criteria.andEqualTo("pigHome",jqid.getPigHome());
            }
        }
        return example;
    }
    public Example createExample(EartagDampness eartagDampness){
        Example example=new Example(EartagDampness.class);
        Example.Criteria criteria = example.createCriteria();
        if(eartagDampness!=null){
            //
            if(!StringUtils.isEmpty(eartagDampness.getId())){
                criteria.andEqualTo("id",eartagDampness.getId());
            }
            //
            if(!StringUtils.isEmpty(eartagDampness.getHeader())){
                criteria.andEqualTo("header",eartagDampness.getHeader());
            }
            //
            if(!StringUtils.isEmpty(eartagDampness.getDeviceId())){
                criteria.andEqualTo("deviceId",eartagDampness.getDeviceId());
            }
            //
            if(!StringUtils.isEmpty(eartagDampness.getCmd())){
                criteria.andEqualTo("cmd",eartagDampness.getCmd());
            }
            //
            if(!StringUtils.isEmpty(eartagDampness.getSerialNo())){
                criteria.andEqualTo("serialNo",eartagDampness.getSerialNo());
            }
            //
            if(!StringUtils.isEmpty(eartagDampness.getValue())){
                criteria.andEqualTo("value",eartagDampness.getValue());
            }
            //
            if(!StringUtils.isEmpty(eartagDampness.getCreateDate())){
                criteria.andEqualTo("createDate",eartagDampness.getCreateDate());
            }
            //
            if(!StringUtils.isEmpty(eartagDampness.getCheckNumber())){
                criteria.andEqualTo("checkNumber",eartagDampness.getCheckNumber());
            }
            //
            if(!StringUtils.isEmpty(eartagDampness.getTail())){
                criteria.andEqualTo("tail",eartagDampness.getTail());
            }
        }
        return example;
    }

    /**
     * 删除
     * @param id
     */
    @Override
    public void delete(Integer id){
        jqidMapper.deleteByPrimaryKey(id);
    }

    /**
     * 修改Jqid
     * @param jqid
     */
    @Override
    public void update(Jqid jqid){

        jqid.setFarmName( farmInfoService.findById(jqid.getFarmNameid()).getName() );
        jqid.setPigHome( pigHomeService.findById(jqid.getPigHomeid()).getName() );

        jqidMapper.updateByPrimaryKey(jqid);
    }

    /**
     * 增加Jqid
     * @param jqid
     */
    @Override
    public void add(Jqid jqid){

        jqid.setFarmName( farmInfoService.findById(jqid.getFarmNameid()).getName() );
        jqid.setPigHome( pigHomeService.findById(jqid.getPigHomeid()).getName() );
        jqid.setJQID(new Date().getTime()+"");
        jqidMapper.insert(jqid);
    }


    /**
     * 根据ID查询Jqid
     * @param id
     * @return
     */
    @Override
    public Jqid findById(Integer id){
        return  jqidMapper.selectByPrimaryKey(id);
    }

    /**
     * 查询Jqid全部数据
     * @return
     */
    @Override
    public List<Jqid> findAll() {
        return jqidMapper.selectAll();
    }

    @Override
    public String findDeviceIdByJQcode(String serialNo) {
        // 根据序列号读取设备id
        Jqid jqidObj = jqidMapper.getDeviceIdByJQcode(serialNo);
        String deviceId = jqidObj.getJQID();
        return deviceId;
    }
    @Autowired
    private EartagDampnessMapper eartagDampnessMapper;
    @Autowired
    private EartagTemperatureMapper eartagTemperatureMapper;
    @Override
    public Map searchData(Map map) {
        String startTime1 = (String) map.get("startTime");
        String endTime1 = (String) map.get("endTime");
        DateFormat fmt = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        Map map1 = new HashMap();
        if (startTime1 != null && endTime1 != null) {

            Date startTime = null;
            Date endTime = null;
            try {
                startTime = fmt.parse(startTime1);
                endTime = fmt.parse(endTime1);
            } catch (ParseException e) {
                e.printStackTrace();
            }
            EartagDampness eartagDampness = new EartagDampness();
            eartagDampness.setDeviceId(Integer.parseInt((String) map.get("JQID")));
            Example example = createExample(eartagDampness);

            List<EartagDampness> eartagDampnessList = eartagDampnessMapper.selectByExample(example);
            List<EartagDampness> list = new ArrayList();
            for (EartagDampness data : eartagDampnessList) {
                Date timestamp = data.getCreateDate();
                if (startTime.before(timestamp) && endTime.after(timestamp)) {
                    list.add(data);
                }
            }
            List dampnessList = new ArrayList();
            List dampnessTimeList = new ArrayList();

            for (EartagDampness data : list) {
                dampnessList.add(data.getValue());
                dampnessTimeList.add(fmt.format(data.getCreateDate()));
            }
            map1.put("dampnessValue", dampnessList);
            map1.put("dampnessTime", dampnessTimeList);


            EartagTemperature eartagTemperature = new EartagTemperature();
            eartagTemperature.setDeviceId(Integer.parseInt((String) map.get("JQID")));
            Example example1 = createExample(eartagTemperature);
            List<EartagTemperature> eartagTemperatureMapperList = eartagTemperatureMapper.selectByExample(example1);
            List<EartagTemperature> list1 = new ArrayList();
            for (EartagTemperature data : eartagTemperatureMapperList) {
                Date timestamp = data.getCreateDate();
                if (startTime.before(timestamp) && endTime.after(timestamp)) {
                    list1.add(data);
                }
            }
            List eartagTemperaList = new ArrayList();
            List eartagTemperaTimeList = new ArrayList();

            for (EartagTemperature data : list1) {
                eartagTemperaList.add(data.getValue());
                eartagTemperaTimeList.add(fmt.format(data.getCreateDate()));
            }
            map1.put("temperaValue", eartagTemperaList);
            map1.put("temperaTime", eartagTemperaTimeList);
        }
        return map1;
    }
    public Example createExample(EartagTemperature eartagTemperature){
        Example example=new Example(EartagTemperature.class);
        Example.Criteria criteria = example.createCriteria();
        if(eartagTemperature!=null){
            // id
            if(!StringUtils.isEmpty(eartagTemperature.getId())){
                criteria.andEqualTo("id",eartagTemperature.getId());
            }
            //
            if(!StringUtils.isEmpty(eartagTemperature.getHeader())){
                criteria.andEqualTo("header",eartagTemperature.getHeader());
            }
            //
            if(!StringUtils.isEmpty(eartagTemperature.getDeviceId())){
                criteria.andEqualTo("deviceId",eartagTemperature.getDeviceId());
            }
            //
            if(!StringUtils.isEmpty(eartagTemperature.getCmd())){
                criteria.andEqualTo("cmd",eartagTemperature.getCmd());
            }
            //
            if(!StringUtils.isEmpty(eartagTemperature.getSerialNo())){
                criteria.andEqualTo("serialNo",eartagTemperature.getSerialNo());
            }
            //
            if(!StringUtils.isEmpty(eartagTemperature.getValue())){
                criteria.andEqualTo("value",eartagTemperature.getValue());
            }
            //
            if(!StringUtils.isEmpty(eartagTemperature.getCreateDate())){
                criteria.andEqualTo("createDate",eartagTemperature.getCreateDate());
            }
            //
            if(!StringUtils.isEmpty(eartagTemperature.getCheckNumber())){
                criteria.andEqualTo("checkNumber",eartagTemperature.getCheckNumber());
            }
            //
            if(!StringUtils.isEmpty(eartagTemperature.getTail())){
                criteria.andEqualTo("tail",eartagTemperature.getTail());
            }
        }
        return example;
    }
}
