package com.huimv.eartag.manager.service.impl;

import com.huimv.common.date.DateUtil;
import com.huimv.eartag.manager.dao.EartagDampnessMapper;
import com.huimv.eartag.manager.dao.EartagTemperatureMapper;
import com.huimv.eartag.manager.pojo.EartagDampness;
import com.huimv.eartag.manager.pojo.EartagData;
import com.huimv.eartag.manager.pojo.EartagTemperature;
import com.huimv.eartag.manager.service.EartagDampnessService;
import com.huimv.eartag.manager.service.EartagDataService;

import com.huimv.eartag.manager.service.EartagTemperatureService;
import com.huimv.eartag.manager.utils.Const;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.text.ParseException;

/**
 * @Project : huimv.shiwan
 * @Package : com.huimv.biosafety.uface.controller
 * @Description : TODO
 * @Version : 1.0
 * @Author : ZhuoNing
 * @Create : 2020-12-25
 **/
@Slf4j
@Component
public class ReceivePackageSerivce {

    @Autowired
    private EartagDataService eartagDataService;
    @Autowired
    private EartagTemperatureMapper temperatureMapper;
    @Autowired
    private EartagTemperatureService temperatureService;
    @Autowired
    private EartagDampnessMapper dampnessMapper;
    @Autowired
    private EartagDampnessService dampnessService;

    /**
     * @Method      : handleEartagData
     * @Description : 处理耳标数据
     * @Params      : [clientMessageArray]
     * @Return      : java.lang.String
     * 
     * @Author      : ZhuoNing
     * @Date        : 2021/1/16       
     * @Time        : 12:08
     */
    public String handleEartagData(String[] clientMessageArray) throws ParseException {
        log.info("开始添加耳标数据......");
        String commandHeader = clientMessageArray[0];
        String deviceId = clientMessageArray[1];
        String cmd = clientMessageArray[2];
        String version = clientMessageArray[3];
        String eartagId = clientMessageArray[4];
        String serial = clientMessageArray[5];
        String dl = clientMessageArray[6];
        String nbwd = clientMessageArray[7];
        String ntc = clientMessageArray[8];
        String ebwd = "";
        String ydl = clientMessageArray[9];
        String cqs = clientMessageArray[10];
        String rssi = clientMessageArray[11];
        String timestamp = clientMessageArray[12];
        String checkNumber = clientMessageArray[13];
        String commandTail = clientMessageArray[14];

        //
        EartagData eartagData = new EartagData();
        eartagData.setHeader(commandHeader);
        eartagData.setCMD(Integer.parseInt(cmd));
        eartagData.setSBID(Integer.parseInt(deviceId));
        eartagData.setVersion(version);
        eartagData.setSerial(Integer.parseInt(serial));
        eartagData.setEartagId(eartagId);
        eartagData.setDl(Integer.parseInt(dl));
        eartagData.setNBWD(Integer.parseInt(nbwd));
        eartagData.setEBWD(0.0);
        eartagData.setNtc(Integer.parseInt(ntc));
        eartagData.setYDL(Integer.parseInt(ydl));
        eartagData.setCQS(Integer.parseInt(cqs));
        eartagData.setRSSYI(Integer.parseInt(rssi));
        eartagData.setTimestamp(DateUtil.parseDateTime(DateUtil.buildDateTimeString(timestamp)));
        eartagData.setCheckNumber(Integer.parseInt(checkNumber));
        eartagData.setMLW(commandTail);
        // 保存耳标数据
        eartagDataService.add(eartagData);
        log.info(Const.SAVE_EARTAG_SUCCESS);
        StringBuilder returnSb = new StringBuilder();
//        return returnSb.append("hm").append("+").append(6).append("+").append(0).append("+").append(6).append("+").append("end").toString();
        return "hm+6+0+6+end";
    }

    /**
     * @Method      : _handleEartagDampness
     * @Description : 处理网关湿度
     * @Params      : [clientMessageArray]
     * @Return      : java.lang.String
     *
     * @Author      : ZhuoNing
     * @Date        : 2021/1/15
     * @Time        : 17:47
     */
    public String handleEartagDampness(String[] clientMessageArray) throws ParseException {
        String header = clientMessageArray[0];
        String deviceId = clientMessageArray[1];
        String cmd = clientMessageArray[2];
        String serialNo = clientMessageArray[3];
        String value = clientMessageArray[4];
        String timestamp = clientMessageArray[5];
        String checkCode = clientMessageArray[6];
        String tail = clientMessageArray[7];
        EartagDampness eartagDampnessPojo = new EartagDampness();
        eartagDampnessPojo.setHeader(header);
        eartagDampnessPojo.setDeviceId(Integer.parseInt(deviceId));
        eartagDampnessPojo.setCmd(Integer.parseInt(cmd));
        eartagDampnessPojo.setSerialNo(Integer.parseInt(serialNo));
        eartagDampnessPojo.setValue(Double.parseDouble(value));
        eartagDampnessPojo.setCreateDate(DateUtil.parseDateTime(DateUtil.buildDateTimeString(timestamp)));
        eartagDampnessPojo.setCheckNumber(Integer.parseInt(checkCode));
        eartagDampnessPojo.setTail(tail);
        dampnessMapper.insert(eartagDampnessPojo);
//        dampnessService.add(eartagDampnessPojo);
        log.info(Const.SAVE_DAMPNESS_SUCCESS);
        return "hm+5+0+8+end";
    }

    /**
     * @Method      : _handleEartagTemperature
     * @Description : 处理网关温度
     * @Params      : [clientMessageArray]
     * @Return      : java.lang.String
     *
     * @Author      : ZhuoNing
     * @Date        : 2021/1/15
     * @Time        : 17:46
     */
    public String handleEartagTemperature(String[] clientMessageArray) throws ParseException {
        String header = clientMessageArray[0];
        String deviceId = clientMessageArray[1];
        String cmd = clientMessageArray[2];
        String serialNo = clientMessageArray[3];
        String value = clientMessageArray[4];
        String timestamp = clientMessageArray[5];
        String checkCode = clientMessageArray[6];
        String tail = clientMessageArray[7];
        EartagTemperature EartagTemperaturePojo = new EartagTemperature();
        EartagTemperaturePojo.setHeader(header);
        EartagTemperaturePojo.setDeviceId(Integer.parseInt(deviceId));
        EartagTemperaturePojo.setCmd(Integer.parseInt(cmd));
        EartagTemperaturePojo.setSerialNo(Integer.parseInt(serialNo));
        EartagTemperaturePojo.setValue(Double.parseDouble(value));
        EartagTemperaturePojo.setCreateDate(DateUtil.parseDateTime(DateUtil.buildDateTimeString(timestamp)));
        EartagTemperaturePojo.setCheckNumber(Integer.parseInt(checkCode));
        EartagTemperaturePojo.setTail(tail);
        temperatureMapper.insert(EartagTemperaturePojo);
//        temperatureService.add(EartagTemperaturePojo);
        log.info(Const.SAVE_TEMPERATURE_SUCCESS);
        return "hm+4+0+7+end";
    }
}
