package com.huimv.eartag.monitor.controller;


import com.github.pagehelper.PageInfo;

import com.huimv.eartag.monitor.entity.Result;
import com.huimv.eartag.monitor.entity.StatusCode;
import com.huimv.eartag.monitor.pojo.EartagDampness;
import com.huimv.eartag.monitor.service.EartagDampnessService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/****
 * @Author:shenkunlin
 * @Description:
 * @Date 2019/6/14 0:18
 *****/

@RestController
@RequestMapping("/eartagDampness")
@CrossOrigin
public class EartagDampnessController {

    @Autowired
    private EartagDampnessService eartagDampnessService;

    /***
     * EartagDampness分页条件搜索实现
     * @param eartagDampness
     * @param page
     * @param size
     * @return
     */
    @PostMapping(value = "/search/{page}/{size}" )
    public Result<PageInfo> findPage(@RequestBody(required = false)  EartagDampness eartagDampness, @PathVariable  int page, @PathVariable  int size){
        //调用EartagDampnessService实现分页条件查询EartagDampness
        PageInfo<EartagDampness> pageInfo = eartagDampnessService.findPage(eartagDampness, page, size);
        return new Result(true, StatusCode.OK,"查询成功",pageInfo);
    }

    /***
     * EartagDampness分页搜索实现
     * @param page:当前页
     * @param size:每页显示多少条
     * @return
     */
    @GetMapping(value = "/search/{page}/{size}" )
    public Result<PageInfo> findPage(@PathVariable  int page, @PathVariable  int size){
        //调用EartagDampnessService实现分页查询EartagDampness
        PageInfo<EartagDampness> pageInfo = eartagDampnessService.findPage(page, size);
        return new Result<PageInfo>(true,StatusCode.OK,"查询成功",pageInfo);
    }

    /***
     * 多条件搜索品牌数据
     * @param eartagDampness
     * @return
     */
    @PostMapping(value = "/search" )
    public Result<List<EartagDampness>> findList(@RequestBody(required = false)  EartagDampness eartagDampness){
        //调用EartagDampnessService实现条件查询EartagDampness
        List<EartagDampness> list = eartagDampnessService.findList(eartagDampness);
        return new Result<List<EartagDampness>>(true,StatusCode.OK,"查询成功",list);
    }

    /***
     * 根据ID删除品牌数据
     * @param id
     * @return
     */
    @DeleteMapping(value = "/{id}" )
    public Result delete(@PathVariable Integer id){
        //调用EartagDampnessService实现根据主键删除
        eartagDampnessService.delete(id);
        return new Result(true,StatusCode.OK,"删除成功");
    }

    /***
     * 修改EartagDampness数据
     * @param eartagDampness
     * @param id
     * @return
     */
    @PutMapping(value="/{id}")
    public Result update(@RequestBody  EartagDampness eartagDampness,@PathVariable Integer id){
        //设置主键值
        eartagDampness.setId(id);
        //调用EartagDampnessService实现修改EartagDampness
        eartagDampnessService.update(eartagDampness);
        return new Result(true,StatusCode.OK,"修改成功");
    }

    /***
     * 新增EartagDampness数据
     * @param eartagDampness
     * @return
     */
    @PostMapping
    public Result add(@RequestBody   EartagDampness eartagDampness){
        //调用EartagDampnessService实现添加EartagDampness
        eartagDampnessService.add(eartagDampness);
        return new Result(true,StatusCode.OK,"添加成功");
    }

    /***
     * 根据ID查询EartagDampness数据
     * @param id
     * @return
     */
    @GetMapping("/{id}")
    public Result<EartagDampness> findById(@PathVariable Integer id){
        //调用EartagDampnessService实现根据主键查询EartagDampness
        EartagDampness eartagDampness = eartagDampnessService.findById(id);
        return new Result<EartagDampness>(true,StatusCode.OK,"查询成功",eartagDampness);
    }

    /***
     * 查询EartagDampness全部数据
     * @return
     */
    @GetMapping
    public Result<List<EartagDampness>> findAll(){
        //调用EartagDampnessService实现查询所有EartagDampness
        List<EartagDampness> list = eartagDampnessService.findAll();
        return new Result<List<EartagDampness>>(true, StatusCode.OK,"查询成功",list) ;
    }
}
