package com.huimv.eartag.monitor.controller;



import com.github.pagehelper.PageInfo;
import com.huimv.eartag.monitor.entity.Result;
import com.huimv.eartag.monitor.entity.StatusCode;
import com.huimv.eartag.monitor.pojo.Jqid;
import com.huimv.eartag.monitor.service.JqidService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/****
 * @Author:shenkunlin
 * @Description:
 * @Date 2019/6/14 0:18
 *****/

@RestController
@RequestMapping("/jqid")
@CrossOrigin
public class JqidController {

    @Autowired
    private JqidService jqidService;

    /***
     * Jqid分页条件搜索实现
     * @param jqid
     * @param page
     * @param size
     * @return
     */
    @PostMapping(value = "/search/{page}/{size}" )
    public Result<PageInfo> findPage(@RequestBody(required = false) Jqid jqid, @PathVariable  int page, @PathVariable  int size){
        //调用JqidService实现分页条件查询Jqid
        PageInfo<Jqid> pageInfo = jqidService.findPage(jqid, page, size);
        return new Result(true, StatusCode.OK,"查询成功",pageInfo);
    }

    /***
     * Jqid分页搜索实现
     * @param page:当前页
     * @param size:每页显示多少条
     * @return
     */
    @GetMapping(value = "/search/{page}/{size}" )
    public Result<PageInfo> findPage(@PathVariable  int page, @PathVariable  int size){
        //调用JqidService实现分页查询Jqid
        PageInfo<Jqid> pageInfo = jqidService.findPage(page, size);
        return new Result<PageInfo>(true,StatusCode.OK,"查询成功",pageInfo);
    }

    /***
     * 多条件搜索品牌数据
     * @param jqid
     * @return
     */
    @PostMapping(value = "/search" )
    public Result<List<Jqid>> findList(@RequestBody(required = false)  Jqid jqid){
        //调用JqidService实现条件查询Jqid
        List<Jqid> list = jqidService.findList(jqid);
        return new Result<List<Jqid>>(true,StatusCode.OK,"查询成功",list);
    }

    /***
     * 根据ID删除品牌数据
     * @param id
     * @return
     */
    @DeleteMapping(value = "/{id}" )
    public Result delete(@PathVariable Integer id){
        //调用JqidService实现根据主键删除
        jqidService.delete(id);
        return new Result(true,StatusCode.OK,"删除成功");
    }

    /***
     * 修改Jqid数据
     * @param jqid
     * @param id
     * @return
     */
    @PutMapping(value="/{id}")
    public Result update(@RequestBody  Jqid jqid,@PathVariable Integer id){
        //设置主键值
        jqid.setId(id);
        //调用JqidService实现修改Jqid
        jqidService.update(jqid);
        return new Result(true,StatusCode.OK,"修改成功");
    }

    /***
     * 新增Jqid数据
     * @param jqid
     * @return
     */
    @PostMapping
    public Result add(@RequestBody   Jqid jqid){
        //调用JqidService实现添加Jqid
        jqidService.add(jqid);
        return new Result(true, StatusCode.OK,"添加成功");
    }

    /***
     * 根据ID查询Jqid数据
     * @param id
     * @return
     */
    @GetMapping("/{id}")
    public Result<Jqid> findById(@PathVariable Integer id){
        //调用JqidService实现根据主键查询Jqid
        Jqid jqid = jqidService.findById(id);
        return new Result<Jqid>(true,StatusCode.OK,"查询成功",jqid);
    }

    /***
     * 查询Jqid全部数据
     * @return
     */
    @GetMapping
    public Result<List<Jqid>> findAll(){
        //调用JqidService实现查询所有Jqid
        List<Jqid> list = jqidService.findAll();
        return new Result<List<Jqid>>(true, StatusCode.OK,"查询成功",list) ;
    }
}
