package com.huimv.eartag.monitor.service.impl;



import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.huimv.eartag.monitor.dao.EartagDataMapper;
import com.huimv.eartag.monitor.pojo.EartagData;
import com.huimv.eartag.monitor.service.EartagDataService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;
import tk.mybatis.mapper.entity.Example;

import java.util.List;

/****
 * @Author:shenkunlin
 * @Description:EartagData业务层接口实现类
 * @Date 2019/6/14 0:16
 *****/
@Service
public class EartagDataServiceImpl implements EartagDataService {

    @Autowired
    private EartagDataMapper eartagDataMapper;


    /**
     * EartagData条件+分页查询
     * @param eartagData 查询条件
     * @param page 页码
     * @param size 页大小
     * @return 分页结果
     */
    @Override
    public PageInfo<EartagData> findPage(EartagData eartagData, int page, int size){
        //分页
        PageHelper.startPage(page,size);
        //搜索条件构建
        Example example = createExample(eartagData);
        //执行搜索
        return new PageInfo<EartagData>(eartagDataMapper.selectByExample(example));
    }

    /**
     * EartagData分页查询
     * @param page
     * @param size
     * @return
     */
    @Override
    public PageInfo<EartagData> findPage(int page, int size){
        //静态分页
        PageHelper.startPage(page,size);
        //分页查询
        return new PageInfo<EartagData>(eartagDataMapper.selectAll());
    }

    /**
     * EartagData条件查询
     * @param eartagData
     * @return
     */
    @Override
    public List<EartagData> findList(EartagData eartagData){
        //构建查询条件
        Example example = createExample(eartagData);
        //根据构建的条件查询数据
        return eartagDataMapper.selectByExample(example);
    }


    /**
     * EartagData构建查询对象
     * @param eartagData
     * @return
     */
    public Example createExample(EartagData eartagData){
        Example example=new Example(EartagData.class);
        Example.Criteria criteria = example.createCriteria();
        if(eartagData!=null){
            // 
            if(!StringUtils.isEmpty(eartagData.getId())){
                    criteria.andEqualTo("id",eartagData.getId());


            }
            // 设备id
            if(!StringUtils.isEmpty(eartagData.getSBID())){
                    criteria.andEqualTo("SBID",eartagData.getSBID());
            }
            // 命令
            if(!StringUtils.isEmpty(eartagData.getCMD())){
                    criteria.andEqualTo("CMD",eartagData.getCMD());
            }
            // 版本
            if(!StringUtils.isEmpty(eartagData.getVersion())){
                    criteria.andEqualTo("version",eartagData.getVersion());
            }
            // 序列号
            if(!StringUtils.isEmpty(eartagData.getSerial())){
                    criteria.andEqualTo("serial",eartagData.getSerial());
            }
            // 耳标id
            if(!StringUtils.isEmpty(eartagData.getEartagId())){
                    criteria.andEqualTo("eartagId",eartagData.getEartagId());
            }
            // 电量
            if(!StringUtils.isEmpty(eartagData.getDl())){
                    criteria.andEqualTo("dl",eartagData.getDl());
            }
            // 内部温度
            if(!StringUtils.isEmpty(eartagData.getNBWD())){
                    criteria.andEqualTo("NBWD",eartagData.getNBWD());
            }
            // 耳标温度
            if(!StringUtils.isEmpty(eartagData.getEBWD())){
                    criteria.andEqualTo("EBWD",eartagData.getEBWD());
            }
            // ntc
            if(!StringUtils.isEmpty(eartagData.getNtc())){
                    criteria.andEqualTo("ntc",eartagData.getNtc());
            }
            // 运动量
            if(!StringUtils.isEmpty(eartagData.getYDL())){
                    criteria.andEqualTo("YDL",eartagData.getYDL());
            }
            // 重启数
            if(!StringUtils.isEmpty(eartagData.getCQS())){
                    criteria.andEqualTo("CQS",eartagData.getCQS());
            }
            // rssi
            if(!StringUtils.isEmpty(eartagData.getRSSYI())){
                    criteria.andEqualTo("RSSYI",eartagData.getRSSYI());
            }
            // 时间戳
            if(!StringUtils.isEmpty(eartagData.getTimestamp())){
                    criteria.andEqualTo("timestamp",eartagData.getTimestamp());
            }
            // 校验码
            if(!StringUtils.isEmpty(eartagData.getCheckNumber())){
                    criteria.andEqualTo("checkNumber",eartagData.getCheckNumber());
            }
            // 命令尾
            if(!StringUtils.isEmpty(eartagData.getMLW())){
                    criteria.andEqualTo("MLW",eartagData.getMLW());
            }
        }
        return example;
    }

    /**
     * 删除
     * @param id
     */
    @Override
    public void delete(Integer id){
        eartagDataMapper.deleteByPrimaryKey(id);
    }

    /**
     * 修改EartagData
     * @param eartagData
     */
    @Override
    public void update(EartagData eartagData){
        eartagDataMapper.updateByPrimaryKey(eartagData);
    }

    /**
     * 增加EartagData
     * @param eartagData
     */
    @Override
    public void add(EartagData eartagData){
        eartagDataMapper.insert(eartagData);
    }

    /**
     * 根据ID查询EartagData
     * @param id
     * @return
     */
    @Override
    public EartagData findById(Integer id){
        return  eartagDataMapper.selectByPrimaryKey(id);
    }

    /**
     * 查询EartagData全部数据
     * @return
     */
    @Override
    public List<EartagData> findAll() {
        return eartagDataMapper.selectAll();
    }




    @Override
    public Integer findYDL(String eartagId) {
        return eartagDataMapper.getDeviceIdByJQcode(eartagId);
    }
}
