package com.huimv.eartag.monitor.service.impl;



import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.huimv.eartag.monitor.dao.JqidMapper;
import com.huimv.eartag.monitor.pojo.Jqid;
import com.huimv.eartag.monitor.service.FarmInfoService;
import com.huimv.eartag.monitor.service.JqidService;
import com.huimv.eartag.monitor.service.PigHomeService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;
import tk.mybatis.mapper.entity.Example;

import java.util.Date;
import java.util.List;

/****
 * @Author:shenkunlin
 * @Description:Jqid业务层接口实现类
 * @Date 2019/6/14 0:16
 *****/
@Service
@Slf4j
public class JqidServiceImpl implements JqidService {

    @Autowired
    private JqidMapper jqidMapper;


    @Autowired
    private FarmInfoService farmInfoService;

    @Autowired
    private PigHomeService pigHomeService ;
    /**
     * Jqid条件+分页查询
     * @param jqid 查询条件
     * @param page 页码
     * @param size 页大小
     * @return 分页结果
     */
    @Override
    public PageInfo<Jqid> findPage(Jqid jqid, int page, int size){
        //分页
        PageHelper.startPage(page,size);
        //搜索条件构建
        Example example = createExample(jqid);
        //执行搜索
        return new PageInfo<Jqid>(jqidMapper.selectByExample(example));
    }

    /**
     * Jqid分页查询
     * @param page
     * @param size
     * @return
     */
    @Override
    public PageInfo<Jqid> findPage(int page, int size){
        //静态分页
        PageHelper.startPage(page,size);
        //分页查询
        return new PageInfo<Jqid>(jqidMapper.selectAll());
    }

    /**
     * Jqid条件查询
     * @param jqid
     * @return
     */
    @Override
    public List<Jqid> findList(Jqid jqid){
        //构建查询条件
        Example example = createExample(jqid);
        //根据构建的条件查询数据
        return jqidMapper.selectByExample(example);
    }


    /**
     * Jqid构建查询对象
     * @param jqid
     * @return
     */
    public Example createExample(Jqid jqid){
        Example example=new Example(Jqid.class);
        Example.Criteria criteria = example.createCriteria();
        if(jqid!=null){
            // 
            if(!StringUtils.isEmpty(jqid.getId())){
                    criteria.andEqualTo("id",jqid.getId());
            }
            // 牧场名称
            if(!StringUtils.isEmpty(jqid.getFarmNameid())){
                    criteria.andEqualTo("farmNameid",jqid.getFarmNameid());
            }
            // 猪舍名称
            if(!StringUtils.isEmpty(jqid.getPigHomeid())){
                    criteria.andEqualTo("pigHomeid",jqid.getPigHomeid());
            }
            // 备注
            if(!StringUtils.isEmpty(jqid.getRemarmk())){
                    criteria.andEqualTo("remarmk",jqid.getRemarmk());
            }
            // 机器id
            if(!StringUtils.isEmpty(jqid.getJQID())){
                    criteria.andEqualTo("JQID",jqid.getJQID());
            }
            // 机器编码
            if(!StringUtils.isEmpty(jqid.getJQcode())){
                    criteria.andEqualTo("JQcode",jqid.getJQcode());
            }
            // 机器名称
            if(!StringUtils.isEmpty(jqid.getFarmName())){
                    criteria.andEqualTo("farmName",jqid.getFarmName());
            }
            // 猪舍名称
            if(!StringUtils.isEmpty(jqid.getPigHome())){
                    criteria.andEqualTo("pigHome",jqid.getPigHome());
            }
        }
        return example;
    }

    /**
     * 删除
     * @param id
     */
    @Override
    public void delete(Integer id){
        jqidMapper.deleteByPrimaryKey(id);
    }

    /**
     * 修改Jqid
     * @param jqid
     */
    @Override
    public void update(Jqid jqid){

        jqid.setFarmName( farmInfoService.findById(jqid.getFarmNameid()).getName() );
        jqid.setPigHome( pigHomeService.findById(jqid.getPigHomeid()).getName() );

        jqidMapper.updateByPrimaryKey(jqid);
    }

    /**
     * 增加Jqid
     * @param jqid
     */
    @Override
    public void add(Jqid jqid){

        jqid.setFarmName( farmInfoService.findById(jqid.getFarmNameid()).getName() );
        jqid.setPigHome( pigHomeService.findById(jqid.getPigHomeid()).getName() );
        jqid.setJQID(new Date().getTime()+"");
        jqidMapper.insert(jqid);
    }

    /**
     * 根据ID查询Jqid
     * @param id
     * @return
     */
    @Override
    public Jqid findById(Integer id){
        return  jqidMapper.selectByPrimaryKey(id);
    }

    /**
     * 查询Jqid全部数据
     * @return
     */
    @Override
    public List<Jqid> findAll() {
        return jqidMapper.selectAll();
    }

    @Override
    public String findDeviceIdByJQcode(String serialNo) {
        // 根据序列号读取设备id
        Jqid jqidPojo = jqidMapper.getDeviceIdByJQcode(serialNo);
        String deviceId = "";
        if(jqidPojo == null){
            deviceId = "0000";
            log.error("未查询到设备id(机器id)");
        }
         deviceId = jqidPojo.getJQID();
        return deviceId;
    }
}
