package com.huimv.eartag.monitor.service.impl;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.huimv.eartag.monitor.dao.PigHomeMapper;
import com.huimv.eartag.monitor.pojo.PigHome;
import com.huimv.eartag.monitor.service.FarmInfoService;
import com.huimv.eartag.monitor.service.PigHomeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;
import tk.mybatis.mapper.entity.Example;

import java.util.List;

/****
 * @Author:shenkunlin
 * @Description:PigHome业务层接口实现类
 * @Date 2019/6/14 0:16
 *****/
@Service
public class PigHomeServiceImpl implements PigHomeService {

    @Autowired
    private PigHomeMapper pigHomeMapper;
    @Autowired
    private FarmInfoService farmInfoService;

    /**
     * PigHome条件+分页查询
     * @param pigHome 查询条件
     * @param page 页码
     * @param size 页大小
     * @return 分页结果
     */
    @Override
    public PageInfo<PigHome> findPage(PigHome pigHome, int page, int size){
        //分页
        PageHelper.startPage(page,size);
        //搜索条件构建
        Example example = createExample(pigHome);
        //执行搜索
        return new PageInfo<PigHome>(pigHomeMapper.selectByExample(example));
    }

    /**
     * PigHome分页查询
     * @param page
     * @param size
     * @return
     */
    @Override
    public PageInfo<PigHome> findPage(int page, int size){
        //静态分页
        PageHelper.startPage(page,size);
        //分页查询
        return new PageInfo<PigHome>(pigHomeMapper.selectAll());
    }

    /**
     * PigHome条件查询
     * @param pigHome
     * @return
     */
    @Override
    public List<PigHome> findList(PigHome pigHome){
        //构建查询条件
        Example example = createExample(pigHome);
        //根据构建的条件查询数据
        return pigHomeMapper.selectByExample(example);
    }


    /**
     * PigHome构建查询对象
     * @param pigHome
     * @return
     */
    public Example createExample(PigHome pigHome){
        Example example=new Example(PigHome.class);
        Example.Criteria criteria = example.createCriteria();
        if(pigHome!=null){
            // 
            if(!StringUtils.isEmpty(pigHome.getId())){
                    criteria.andEqualTo("id",pigHome.getId());
            }
            // 猪舍名称
            if(!StringUtils.isEmpty(pigHome.getName())){
                    criteria.andLike("name","%"+pigHome.getName()+"%");
            }
            // 牧场id
            if(!StringUtils.isEmpty(pigHome.getFarmId())){
                    criteria.andEqualTo("farmId",pigHome.getFarmId());
            }
            // 备注
            if(!StringUtils.isEmpty(pigHome.getRemark())){
                    criteria.andEqualTo("remark",pigHome.getRemark());
            }
            // 牧场名称
            if(!StringUtils.isEmpty(pigHome.getFarmName())){
                    criteria.andEqualTo("farmName",pigHome.getFarmName());
            }
        }
        return example;
    }

    /**
     * 删除
     * @param id
     */
    @Override
    public void delete(Integer id){
        pigHomeMapper.deleteByPrimaryKey(id);
    }

    /**
     * 修改PigHome
     * @param pigHome
     */
    @Override
    public void update(PigHome pigHome){

        pigHome.setFarmName( farmInfoService.findById(pigHome.getFarmId()).getName() );
        pigHomeMapper.updateByPrimaryKey(pigHome);
    }

    /**
     * 增加PigHome
     * @param pigHome
     */
    @Override
    public void add(PigHome pigHome){
        pigHomeMapper.insert(pigHome);
    }

    /**
     * 根据ID查询PigHome
     * @param id
     * @return
     */
    @Override
    public PigHome findById(Integer id){
        return  pigHomeMapper.selectByPrimaryKey(id);
    }

    /**
     * 查询PigHome全部数据
     * @return
     */
    @Override
    public List<PigHome> findAll() {
        return pigHomeMapper.selectAll();
    }
}
