package com.huimv.eartag.monitor.service.impl;

import com.huimv.common.date.DateUtil;
import com.huimv.eartag.monitor.dao.EartagDampnessMapper;
import com.huimv.eartag.monitor.dao.EartagTemperatureMapper;
import com.huimv.eartag.monitor.pojo.EartagDampness;
import com.huimv.eartag.monitor.pojo.EartagData;
import com.huimv.eartag.monitor.pojo.EartagTemperature;
import com.huimv.eartag.monitor.service.EartagDampnessService;
import com.huimv.eartag.monitor.service.EartagDataService;
import com.huimv.eartag.monitor.service.EartagTemperatureService;
import com.huimv.eartag.monitor.utils.Const;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.text.DecimalFormat;
import java.text.NumberFormat;
import java.text.ParseException;

/**
 * @Project : huimv.shiwan
 * @Package : com.huimv.biosafety.uface.controller
 * @Description : TODO
 * @Version : 1.0
 * @Author : ZhuoNing
 * @Create : 2020-12-25
 **/
@Slf4j
@Component
public class ReceivePackageSerivce {

    @Autowired
    private EartagDataService eartagDataService;
    @Autowired
    private EartagTemperatureMapper temperatureMapper;
    @Autowired
    private EartagTemperatureService temperatureService;
    @Autowired
    private EartagDampnessMapper dampnessMapper;
    @Autowired
    private EartagDampnessService dampnessService;

    /**
     * @Method : handleEartagData
     * @Description : 处理耳标数据
     * @Params : [clientMessageArray]
     * @Return : java.lang.String
     * @Author : ZhuoNing
     * @Date : 2021/1/16
     * @Time : 12:08
     */
    public String handleEartagData(String[] clientMessageArray) throws ParseException {
        log.info("开始添加耳标数据......");
        String commandHeader = clientMessageArray[0];
        String deviceId = clientMessageArray[1];
        String cmd = clientMessageArray[2];
        String version = clientMessageArray[3];
        String eartagId = clientMessageArray[4];
        String serial = clientMessageArray[5];
        String dl = clientMessageArray[6];
        String nbwd = clientMessageArray[7];
        String ntc = clientMessageArray[8];
        String ebwd = "";
        String ydl = clientMessageArray[9];/**********/
        //计算区间运动量

        Integer ydl1 = eartagDataService.findYDL(eartagId);
        //新添加的耳标没有历史数据，设置为0
        if (ydl1 == null) {
            ydl1 = 0;
        }
        Integer qjydl = Integer.parseInt(ydl) - ydl1;

        String cqs = clientMessageArray[10];
        String rssi = clientMessageArray[11];
        String timestamp = clientMessageArray[12];
        String checkNumber = clientMessageArray[13];
        String commandTail = clientMessageArray[14];
        //耳标数据填充
        EartagData eartagData = new EartagData();
        eartagData.setHeader(commandHeader);
        eartagData.setCMD(Integer.parseInt(cmd));
        eartagData.setSBID(Integer.parseInt(deviceId));
        eartagData.setVersion(version);
        eartagData.setSerial(Integer.parseInt(serial));
        eartagData.setQjydl(qjydl);

        eartagData.setEartagId(eartagId);
        //电量不需要处理   89就是89%
        eartagData.setDl(Integer.parseInt(dl));

        eartagData.setNBWD(Integer.parseInt(nbwd) / 100);
        // eartagData.setEBWD(0.0);
        eartagData.setEBWD(ln(Integer.parseInt(ntc)));
        //热敏电阻值，计算耳标温度
        eartagData.setNtc(Integer.parseInt(ntc));
        eartagData.setYDL(Integer.parseInt(ydl));
        eartagData.setCQS(Integer.parseInt(cqs));
        eartagData.setRSSYI(Integer.parseInt(rssi));
        eartagData.setTimestamp(DateUtil.parseDateTime(DateUtil.buildDateTimeString(timestamp)));
        eartagData.setCheckNumber(Integer.parseInt(checkNumber));
        eartagData.setMLW(commandTail);


        eartagDataService.add(eartagData);
        log.info(Const.SAVE_EARTAG_SUCCESS);
        StringBuilder returnSb = new StringBuilder();
//      return returnSb.append("hm").append("+").append(6).append("+").append(0).append("+").append(6).append("+").append("end").toString();
        return "hm+6+0+6+end";
    }

    /**
     * @Method : _handleEartagDampness
     * @Description : 处理网关湿度
     * @Params : [clientMessageArray]
     * @Return : java.lang.String
     * @Author : ZhuoNing
     * @Date : 2021/1/15
     * @Time : 17:47
     */
    public String handleEartagDampness(String[] clientMessageArray) throws ParseException {
        String header = clientMessageArray[0];
        String deviceId = clientMessageArray[1];
        String cmd = clientMessageArray[2];
        String serialNo = clientMessageArray[3];
        String value = clientMessageArray[4];
        String timestamp = clientMessageArray[5];
        String checkCode = clientMessageArray[6];
        String tail = clientMessageArray[7];
        EartagDampness eartagDampnessPojo = new EartagDampness();
        eartagDampnessPojo.setHeader(header);
        eartagDampnessPojo.setDeviceId(Integer.parseInt(deviceId));
        eartagDampnessPojo.setCmd(Integer.parseInt(cmd));
        eartagDampnessPojo.setSerialNo(Integer.parseInt(serialNo));
        eartagDampnessPojo.setValue(Double.parseDouble(value));
        eartagDampnessPojo.setCreateDate(DateUtil.parseDateTime(DateUtil.buildDateTimeString(timestamp)));
        eartagDampnessPojo.setCheckNumber(Integer.parseInt(checkCode));
        eartagDampnessPojo.setTail(tail);
        dampnessMapper.insert(eartagDampnessPojo);
//        dampnessService.add(eartagDampnessPojo);
        log.info(Const.SAVE_DAMPNESS_SUCCESS);
        return "hm+5+0+8+end";
    }

    /**
     * @Method : _handleEartagTemperature
     * @Description : 处理网关温度
     * @Params : [clientMessageArray]
     * @Return : java.lang.String
     * @Author : ZhuoNing
     * @Date : 2021/1/15
     * @Time : 17:46
     */
    public String handleEartagTemperature(String[] clientMessageArray) throws ParseException {
        String header = clientMessageArray[0];
        String deviceId = clientMessageArray[1];
        String cmd = clientMessageArray[2];
        String serialNo = clientMessageArray[3];
        String value = clientMessageArray[4];
        String timestamp = clientMessageArray[5];
        String checkCode = clientMessageArray[6];
        String tail = clientMessageArray[7];
        EartagTemperature EartagTemperaturePojo = new EartagTemperature();
        EartagTemperaturePojo.setHeader(header);
        EartagTemperaturePojo.setDeviceId(Integer.parseInt(deviceId));
        EartagTemperaturePojo.setCmd(Integer.parseInt(cmd));
        EartagTemperaturePojo.setSerialNo(Integer.parseInt(serialNo));
        EartagTemperaturePojo.setValue(Double.parseDouble(value) / 10);
        EartagTemperaturePojo.setCreateDate(DateUtil.parseDateTime(DateUtil.buildDateTimeString(timestamp)));
        EartagTemperaturePojo.setCheckNumber(Integer.parseInt(checkCode));
        EartagTemperaturePojo.setTail(tail);
        temperatureMapper.insert(EartagTemperaturePojo);
//        temperatureService.add(EartagTemperaturePojo);
        log.info(Const.SAVE_TEMPERATURE_SUCCESS);
        return "hm+4+0+7+end";
    }


    public static String swapHex(String src) {
        String target = "";
        for (int i = src.length() - 1; i > 0; i -= 2) {
            target += src.substring(i - 1, i + 1);
        }
        return target;
    }


    public static String numberFormater(double d) {
        DecimalFormat nf = new DecimalFormat();
        nf.setMaximumFractionDigits(2);
        return nf.format(d);
    }

    public static double A = 0.00335396319311466;
    public static double B = 0.000256376549039663;
    public static double C = 0.00000248933580817244;
    public static double D = 0.0000000753805242068686;
    public static double E = -0.0000000204758173596178;

    //保留一位小数
    public static double changeDouble(Double dou) {
        NumberFormat nf = new DecimalFormat("0.0 ");
        dou = Double.parseDouble(nf.format(dou));
        return dou;
    }

    //温度转换
    public static double ln(int rv) {
        int R_REF = 10000;
        double ln = Math.log((double) rv / R_REF);
        //保留一位小数
        return changeDouble(1 / (A + B * ln + C * Math.pow(ln, 2) + D * Math.pow(ln, 3) + E * Math.pow(ln, 4)) - 273.15);
    }
}
